import React, { useEffect, useState } from "react";
import Button from "@material-ui/core/Button";
import { Link, useNavigate } from "react-router-dom";
import swal from "sweetalert";
import axios from "axios";
import { isAutheticated } from "src/auth";
import CloudUploadIcon from "@mui/icons-material/CloudUpload";
import DeleteSharpIcon from "@mui/icons-material/DeleteSharp";
import { TagsInput } from "react-tag-input-component";
import {
  Box,
  FormControl,
  IconButton,
  MenuItem,
  Select,
  TextField,
} from "@mui/material";
import { Editor } from "react-draft-wysiwyg";
import { EditorState, convertToRaw } from "draft-js";
import { stateToHTML } from "draft-js-export-html";
// import { WebsiteURL } from '../WebsiteURL'

const CreateBlog = () => {
  const token = isAutheticated();
  const navigate = useNavigate();

  const [loading, setLoading] = useState(false);

  const [imagesPreview, setImagesPreview] = useState([]);
  // const [allimage, setAllImage] = useState([]);
  const [title, setTitle] = useState("");
  const [tag, setTag] = useState([]); //tags array
  const [productImages, setProductImages] = useState([]);
  const [blogContent, setBlogContent] = useState(EditorState.createEmpty());
  // const [htmlData, setHtmlData] = useState();
  const [error, setError] = useState("");

  const handleFileChange = (e) => {
    const files = e.target.files;

    // Check the total number of selected files
    if (productImages.length + files.length > 4) {
      setError("You can only upload up to 4 images.");
      return;
    }

    // Check file types and append to selectedFiles
    const allowedTypes = ["image/jpeg", "image/png", "image/jpg"];
    const selected = [];

    for (let i = 0; i < files.length; i++) {
      if (productImages.length + selected.length >= 4) {
        break; // Don't allow more than 4 images
      }

      if (allowedTypes.includes(files[i].type)) {
        selected.push(files[i]);
      }
    }

    if (selected.length === 0) {
      setError("Please upload only PNG, JPEG, or JPG files.");
    } else {
      setError("");
      setProductImages([...productImages, ...selected]);
    }
  };

  const handelDelete = (image) => {
    const filtered = productImages.filter((item) => item !== image);
    setProductImages(filtered);
  };

  const handleSubmit = () => {
    setLoading(true);

    const contentState = blogContent.getCurrentContent();
    const htmlData = stateToHTML(contentState);
    console.log(title, typeof htmlData, productImages, tag);
    const formData = new FormData();
    formData.append("title", title);
    formData.append("blog_content", htmlData);

    // Append each file from productImages array individually
    productImages.forEach((file, index) => {
      formData.append(`image${index}`, file);
    });

    // Append each tag from selected array individually
    tag.forEach((tag, index) => {
      formData.append(`tag${index}`, tag);
    });
    for (let entry of formData.entries()) {
      console.log(entry);
    }
    // axios
    //   .post(`/api/v1/blog/create`, formData, {
    //     headers: {
    //       Authorization: `Bearer ${token}`,
    //       "Content-Type": "multipart/form-data",
    //       "Access-Control-Allow-Origin": "*",
    //     },
    //   })
    //   .then((res) => {
    //     swal({
    //       title: "Added",
    //       text: "Product added successfully!",
    //       icon: "success",
    //       button: "ok",
    //     });
    //     setLoading(false);
    //     // navigate("/products", { replace: true });
    //   })
    //   .catch((err) => {
    //     console.log(err);
    //     setLoading(false);
    //     const message = err.response?.data?.message
    //       ? err.response?.data?.message
    //       : "Something went wrong!";
    //     swal({
    //       title: "Warning",
    //       text: message,
    //       icon: "error",
    //       button: "Retry",
    //       dangerMode: true,
    //     });
    //   });
  };
  // console.log(data);
  //   console.log(productImages);
  // To log the content when needed...

  return (
    <div className="container">
      <div className="row">
        <div className="col-12">
          <div
            className="
                    page-title-box
                    d-flex
                    align-items-center
                    justify-content-between
                  "
          >
            <div style={{ fontSize: "22px" }} className="fw-bold">
              Add Product
            </div>
            <div style={{ display: "flex", gap: "1rem" }}>
              <h4 className="mb-0"></h4>
            </div>

            <div className="page-title-right">
              <Button
                variant="contained"
                color="primary"
                style={{
                  fontWeight: "bold",
                  marginBottom: "1rem",
                  textTransform: "capitalize",
                  marginRight: "5px",
                }}
                onClick={() => handleSubmit()}
                disabled={loading}
              >
                {loading ? "Loading" : "Save"}
              </Button>
              <Link to="/blogs">
                <Button
                  variant="contained"
                  color="secondary"
                  style={{
                    fontWeight: "bold",
                    marginBottom: "1rem",
                    textTransform: "capitalize",
                  }}
                >
                  Back
                </Button>
              </Link>
            </div>
          </div>
        </div>
      </div>
      <div className="row">
        <div className="col-lg-6 col-md-6  col-sm-12 my-1">
          <div className="card h-100">
            <div className="card-body px-5">
              <div className="mb-3">
                <label htmlFor="title" className="form-label">
                  Blog Title
                </label>
                <input
                  type="text"
                  className="form-control"
                  id="name"
                  value={title}
                  onChange={(e) => setTitle(e.target.value)}
                />
                {name ? (
                  <>
                    <small className="charLeft mt-4 fst-italic">
                      {25 - name.length} characters left
                    </small>
                  </>
                ) : (
                  <></>
                )}{" "}
              </div>

              <div className="mb-3">
                <label>Tags</label>
                <TagsInput
                  value={tag}
                  onChange={setTag}
                  name="Tags"
                  placeHolder="enter Tags"
                />
                <em style={{ fontSize: "0.8rem" }}>
                  press enter or comma to add new tag
                </em>
              </div>
              <div>
                <label htmlFor="image" className="form-label">
                  Blog Image
                </label>
                <Box>
                  <label htmlFor="upload-Image">
                    <TextField
                      style={{
                        display: "none",
                        width: "350px",
                        height: "350px",
                        borderRadius: "10%",
                      }}
                      fullWidth
                      id="upload-Image"
                      type="file"
                      accept=".jpg , .png ,.jpeg"
                      label="file"
                      variant="outlined"
                      onChange={(e) => handleFileChange(e)}
                    />
                    <Box
                      style={{ borderRadius: "10%" }}
                      sx={{
                        margin: "1rem 0rem",
                        cursor: "pointer",
                        width: "100px",
                        height: "100px",
                        border: "2px solid grey",
                        display: "grid",
                        placeItems: "center",
                        // borderRadius: '50%',

                        "&:hover": {
                          background: "rgba(112,112,112,0.5)",
                        },
                      }}
                    >
                      <CloudUploadIcon
                        style={{
                          color: "grey",
                          margin: "auto",
                          fontSize: "5rem",
                        }}
                        fontSize="large"
                      />
                    </Box>
                  </label>
                </Box>

                {error && <p style={{ color: "red" }}>{error}</p>}
                <p className="pt-1 pl-2 text-secondary">
                  Upload jpg, jpeg and png only*
                </p>
                <Box style={{ display: "flex" }}>
                  {productImages &&
                    productImages.map((image, i) => (
                      <Box marginRight={"2rem"}>
                        <img
                          src={URL.createObjectURL(image)}
                          alt="BlogImage"
                          style={{
                            width: 70,
                            height: 70,

                            marginBottom: "1rem",
                          }}
                        />
                        <DeleteSharpIcon
                          onClick={() => handelDelete(image)}
                          fontSize="small"
                          sx={{
                            color: "white",
                            position: "absolute",
                            cursor: "pointer",
                            padding: "0.2rem",
                            background: "black",
                            borderRadius: "50%",
                          }}
                        />
                        {/* </IconButton> */}
                      </Box>
                    ))}
                </Box>
              </div>

              <div id="createProductFormImage" className="w-25 d-flex">
                {imagesPreview.map((image, index) => (
                  <img
                    className=" w-50 p-1 "
                    key={index}
                    src={image}
                    alt="Blog Image Preview"
                  />
                ))}
              </div>
            </div>
          </div>
        </div>
        <div className="col-lg-6 col-md-6  col-sm-12 my-1">
          <div className="card h-100">
            <div className="card-body px-5">
              <label>Blog Content</label>
              {/* Note : style at _custom.scss */}
              <Editor
                editorState={blogContent}
                toolbarClassName="blog-toolbar"
                wrapperClassName="wrapperClassName"
                editorClassName="blog-content"
                onEditorStateChange={(editorState) => {
                  setBlogContent(editorState);
                }}
              />
              {/* <Button onClick={logContent}>Log Content</Button> */}
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default CreateBlog;
